
<a id='changelog-2023.5.10'></a>
## [2023.5.10] - 2023-05-10

### Added

- Handle hubspot contacts with multiple emails

### Changed

- Updated changelog management and versioning scheme.
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

# [Unreleased]

## [1.0.0] - 2022-07-22

### Added
- Added `mitol.hubspot_api` Hubspot API library.
